#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for generating the polynomial fit information and writing to file.

@author: mark
"""

import logging
import resultsanalysis.resultsoutput.resultswritertofile as resultswritertofile

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def write_poly_data_to_file_split_fit(datapoints, order_list, filename,
                                      pos_subset_list, neg_subset_list):
    """This calculates the polynomial information for fitting to the 2 sub sets
    and writes to file.
    """
    poly_fit_data = generate_poly_fit_data_order_list_split_fit(datapoints,
                                                                order_list,
                                                                pos_subset_list,
                                                                neg_subset_list)
    return write_poly_fit_data_to_file(poly_fit_data, filename, split_fit_range=True)

def write_poly_data_to_file(datapoints, order_list, filename):
    """This calculates the polynomial information, and then outputs the
    information to file.
    """
    poly_fit_data = generate_poly_fit_data_order_list(datapoints, order_list)
    return write_poly_fit_data_to_file(poly_fit_data, filename)

def write_poly_fit_data_to_file(poly_fit_data, filename, **kwargs):
    """This writes the information to file.
    """
    return resultswritertofile.write_poly_fit_information_to_file(poly_fit_data, filename, split_fit_range=kwargs.get("split_fit_range", False))

def generate_poly_fit_data_order_list_split_fit(datapoints, order_list, pos_subset_list, neg_subset_list):
    """This generates the fit data for fitting to the positive and negative regions separately.
    """
    poly_fit_data = {}
    for order in order_list:
        poly_fit_data[order] = generate_polynomial_fit_data_positive_negative_separate_fit(datapoints,
                                                                                           order,
                                                                                           pos_subset_list,
                                                                                           neg_subset_list)
    return poly_fit_data

def generate_poly_fit_data_order_list(datapoints, order_list):
    """This cretes the polynomial fit data for all the given polynomial orders
    for the datapoints given
    """
    poly_fit_data = {}
    for order in order_list:
        poly_fit_data[order] = generate_polynomial_fit_data(datapoints, order)
    return poly_fit_data

def generate_polynomial_fit_data_positive_negative_separate_fit(datapoints, order, pos_subset_list, neg_subset_list):
    """This generates the fit for the positive and negative datapoints separately.
    A dictionary containing the 2 fits are returned.
    """
    positive_fit = generate_polynomial_fit_data_subset(datapoints, order, pos_subset_list)
    negative_fit = generate_polynomial_fit_data_subset(datapoints, order, neg_subset_list)
    return {"positive":positive_fit, "negative":negative_fit}

def generate_polynomial_fit_data_subset(datapoints, order, subset_list):
    """This extracts the subset and then calculates the polynomial fit data.
    """
    datapoints_subset = datapoints.createDatapointsSubGroup(subset_list)
    datapoints_subset.createDataArrays()
    return generate_polynomial_fit_data(datapoints_subset, order)

def generate_polynomial_fit_data(datapoints, order):
    """This creates the polynomial fit data for the given order of polynomial
    for the datapoints given.
    """
    return datapoints.poly_fit_data(order)
