#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for the reading in of solvation energies for a given solvent.

@author: mark
"""

import logging
import resultsanalysis.fileparsing.xmlparsing.solvationreader as solvationreader

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def parse_free_energy_from_file_with_data_arrays(filename):
    """This reads in the information form file to a Datapoints object, and
    creates the data arrays.
    """
    datapoints = parse_free_energy_from_file(filename)
    datapoints.createDataArrays()
    return datapoints

def parse_binding_energy_from_file_with_data_arrays(filename):
    """This reads in the information form file to a Datapoints object, and
    creates the data arrays.
    """
    datapoints = parse_binding_energy_from_file(filename)
    datapoints.createDataArrays()
    return datapoints

def parse_free_energy_from_file(filename):
    """This parses the file and returns a datapoints representation of it.
    """
    solvation_energy_dict = parse_free_energy_info(filename)
    return create_free_energy_datapoints_with_values(solvation_energy_dict)

def parse_binding_energy_from_file(filename):
    """This parses the file and returns a datapoints representation of it.
    """
    solvation_energy_dict = parse_binding_energy_info(filename)
    return create_binding_datapoints_with_values(solvation_energy_dict)

def create_free_energy_datapoints_with_values(solvation_energy_dict):
    """This creates free energy datapoints.
    """
    return solvationreader.create_free_energy_datapoints_with_values(solvation_energy_dict)

def create_binding_datapoints_with_values(solvation_energy_dict):
    """This creates binding datapoints
    """
    return solvationreader.create_binding_datapoints_with_values(solvation_energy_dict)

def parse_free_energy_info(filename):
    """This extracts the solvation information to a dictionary.
    """
    return solvationreader.parse_free_energy_info(filename)

def parse_binding_energy_info(filename):
    """This extracts the solvation information to a dictionary.
    """
    return solvationreader.parse_binding_energy_info(filename)
