#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for writing out the solvation values generated for a solvent map.

Format is 

    Y1 Y2 ... 
X1 S(X1,Y1) S(X1,Y2) ...
X2 S(X2,Y1) S(X2,Y2) ... 
.  .
.  .
.  .
XN S(XN,Y1) S(XN,Y2) ...

@author: mark
"""

import logging
import csv

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def write_matrix_to_file(filename, x_values, y_values, solvation_matrix):
    """This writes the matrix to file.
    """
    with open(filename, 'w') as outfile:
        csv_writer = csv.writer(outfile, delimiter='\t',
                                quoting=csv.QUOTE_NONE)
        csv_writer.writerow(["", *y_values])
        for i in range(len(x_values)):
            csv_writer.writerow(write_matrix_line(x_values[i], solvation_matrix[i]))
    return 0


def write_matrix_line(x_value, solvation_matrix_row):
    """This creates the list of entries ready for writing.
    """
    return ["{:.3f}".format(x_value), *["{:.7f}".format(val) for val in solvation_matrix_row]]
