#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Jul 29 18:50:42 2017

@author: mark
"""

import logging
import unittest
import numpy as np
import solventmapcreator.io.similaritymatrixreader as similaritymatrixreader

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

class SimilarityMatrixReaderTestCase(unittest.TestCase):
    """Test case for similarity matrix reader scripts.
    """
    def setUp(self):
        """Set up before tests
        """
        self.input_filename = "resources/similarity_matrix_file.csv"
        self.expected_dict = {"labels":["poly_fit", "poly_fit2", "poly_fit3"],
                         "value_matrix":np.array([[0.0, 1.0, 4.0],
                                                  [1.0, 0.0, 3.0],
                                                  [4.0, 3.0, 0.0]])}
        self.actual_filelines = similaritymatrixreader.read_similarity_file(self.input_filename)
    def tearDown(self):
        """Clean up after tests.
        """
        del self.input_filename
        del self.expected_dict
        del self.actual_filelines
    def test_parse_similarity_matrix_file(self):
        """Test to see if expected dictionary is returned.
        """
        actual_dict = similaritymatrixreader.parse_similarity_matrix_file(self.input_filename)
        self.assertListEqual(sorted(self.expected_dict.keys()), sorted(actual_dict.keys()))
        self.assertListEqual(self.expected_dict["labels"], actual_dict["labels"])
        np.testing.assert_array_almost_equal(self.expected_dict["value_matrix"],
                                             actual_dict["value_matrix"])
    def test_read_similarity_matrix_line(self):
        """Test to see if expected array is returned.
        """
        expected_array = np.array([0.0, 1.0, 4.0])
        actual_array = similaritymatrixreader.read_similarity_matrix_line("poly_fit", self.actual_filelines[1])
        np.testing.assert_array_almost_equal(expected_array, actual_array)
    def test_read_solvent_names(self):
        """Test to see if expected filenames are returned.
        """
        actual_names = similaritymatrixreader.read_solvent_names(self.actual_filelines[0])
        self.assertListEqual(self.expected_dict["labels"], actual_names)
    def test_read_similarity_file(self):
        """Test to see if expected file lines are read in.
        """
        expected_filelines = [['', 'poly_fit', 'poly_fit2', 'poly_fit3'],
                              ['poly_fit', '0.0000000', '1.0000000', '4.0000000'],
                              ['poly_fit2', '1.0000000', '0.0000000', '3.0000000'],
                              ['poly_fit3', '4.0000000', '3.0000000', '0.0000000']]
        self.assertListEqual(expected_filelines, self.actual_filelines)