#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for testing the polynomialvaluecalculator.

@author: mark
"""

import logging
import numpy as np
import unittest
import solventmapcreator.polynomialanalysis.polynomialvaluecalculator as polyvalcalc

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

class PolynomialValueCalculatorTestCase(unittest.TestCase):
    """Test case for the polynomialvaluecalculator script.
    """
    def setUp(self):
        """Set up for tests
        """
        self.poly_coeff_dict = {"positive":np.array([0.5, 0.0, 1.0]),
                                "negative":np.array([0.5, 0.0, -1.0])}
        self.input_array = np.array([x - 2.0 for x in range(5)])
    def tearDown(self):
        """Clean up after tests.
        """
        del self.poly_coeff_dict
    def test_calculate_polynomial_values(self):
        """Test to see if expected arrays are produced.
        """
        expected_array1 = np.array([-3.5, -0.5, 0.5, 1.5, 4.5])
        actual_array1 = polyvalcalc.calculate_polynomial_values(self.input_array, self.poly_coeff_dict)
        np.testing.assert_array_almost_equal(expected_array1, actual_array1)
        expected_array2 = np.array([4.5, 1.5, 0.5, 1.5, 4.5])
        actual_array2 = polyvalcalc.calculate_polynomial_values(self.input_array, self.poly_coeff_dict["positive"])
        np.testing.assert_array_almost_equal(expected_array2, actual_array2)
        expected_value = -0.5
        actual_value = polyvalcalc.calculate_polynomial_values(-1.0, self.poly_coeff_dict)
        self.assertAlmostEqual(expected_value, actual_value)
    def test_calculate_poly_value_for_array_from_dict(self):
        """Test to see if expected array iss produced.
        """
        expected_array = np.array([-3.5, -0.5, 0.5, 1.5, 4.5])
        actual_array = polyvalcalc.calculate_poly_value_for_array_from_dict(self.input_array, self.poly_coeff_dict)
        np.testing.assert_array_almost_equal(expected_array, actual_array)
    def test_calculate_poly_value_from_dict(self):
        """Test to see if expected values are calculated based on sign.
        """
        expected_value1 = 1.5
        actual_value1 = polyvalcalc.calculate_poly_value_from_dict(1.0, self.poly_coeff_dict)
        self.assertAlmostEqual(expected_value1, actual_value1)
        expected_value2 = -0.5
        actual_value2 = polyvalcalc.calculate_poly_value_from_dict(-1.0, self.poly_coeff_dict)
        self.assertAlmostEqual(expected_value2, actual_value2)
    def test_calculate_polynomial_value(self):
        """Test to see if expected value is returned.
        """
        expected_value = 1.5
        actual_value = polyvalcalc.calculate_polynomial_value(1.0, self.poly_coeff_dict["positive"])
        self.assertAlmostEqual(expected_value, actual_value)
